@@ -1,7 +1,7 @@
+import json
 import re
 import shlex
 import shutil
-import subprocess
 from collections.abc import Iterable, Mapping
 from pathlib import Path
 
@@ -9,7 +9,9 @@ import click
 
 from workstack.cli.config import LoadedConfig, load_config
 from workstack.cli.core import discover_repo_context, ensure_workstacks_dir, worktree_path_for
+from workstack.cli.graphite import get_parent_branch
 from workstack.cli.shell_utils import render_cd_script, write_script_to_temp
+from workstack.cli.subprocess_utils import run_with_error_reporting
 from workstack.core.context import WorkstackContext
 
 _SAFE_COMPONENT_RE = re.compile(r"[^A-Za-z0-9._/-]+")
@@ -220,12 +222,16 @@ def add_worktree(
                     err=True,
                 )
                 raise SystemExit(1)
-            subprocess.run(
+            run_with_error_reporting(
                 ["gt", "create", "--no-interactive", branch],
                 cwd=cwd,
-                check=True,
-                capture_output=True,
-                text=True,
+                error_prefix=f"Failed to create Graphite branch '{branch}'",
+                troubleshooting=[
+                    "Check if branch name is valid",
+                    "Ensure Graphite is properly configured (gt repo init)",
+                    f"Try creating the branch manually: gt create {branch}",
+                    "Disable Graphite: workstack config set use_graphite false",
+                ],
             )
             ctx.git_ops.checkout_branch(cwd, original_branch)
             ctx.git_ops.add_worktree(repo_root, path, branch=branch, ref=None, create_branch=False)
@@ -270,6 +276,37 @@ def quote_env_value(value: str) -> str:
     return f'"{escaped}"'
 
 
+def _create_json_response(
+    *,
+    worktree_name: str,
+    worktree_path: Path,
+    branch_name: str | None,
+    plan_file_path: Path | None,
+    status: str,
+) -> str:
+    """Generate JSON response for create command.
+
+    Args:
+        worktree_name: Name of the worktree
+        worktree_path: Path to the worktree directory
+        branch_name: Git branch name (may be None if not available)
+        plan_file_path: Path to plan file if exists, None otherwise
+        status: Status string ("created" or "exists")
+
+    Returns:
+        JSON string with worktree information
+    """
+    return json.dumps(
+        {
+            "worktree_name": worktree_name,
+            "worktree_path": str(worktree_path),
+            "branch_name": branch_name,
+            "plan_file": str(plan_file_path) if plan_file_path else None,
+            "status": status,
+        }
+    )
+
+
 @click.command("create")
 @click.argument("name", metavar="NAME", required=False)
 @click.option(
@@ -325,6 +362,12 @@ def quote_env_value(value: str) -> str:
     hidden=True,
     help="Output shell script for directory change instead of messages.",
 )
+@click.option(
+    "--json",
+    "output_json",
+    is_flag=True,
+    help="Output JSON with worktree information instead of human-readable messages.",
+)
 @click.pass_obj
 def create(
     ctx: WorkstackContext,
@@ -337,6 +380,7 @@ def create(
     from_current_branch: bool,
     from_branch: str | None,
     script: bool,
+    output_json: bool,
 ) -> None:
     """Create a worktree and write a .env file.
 
@@ -353,6 +397,11 @@ def create(
         click.echo("Cannot use multiple of: --from-current-branch, --from-branch, --plan")
         raise SystemExit(1)
 
+    # Validate --json and --script are mutually exclusive
+    if output_json and script:
+        click.echo("Error: Cannot use both --json and --script", err=True)
+        raise SystemExit(1)
+
     # Validate --keep-plan requires --plan
     if keep_plan and not plan_file:
         click.echo("Error: --keep-plan requires --plan", err=True)
@@ -427,17 +476,47 @@ def create(
     wt_path = worktree_path_for(workstacks_dir, name)
 
     if wt_path.exists():
-        click.echo(f"Worktree path already exists: {wt_path}")
-        raise SystemExit(1)
+        if output_json:
+            # For JSON output, emit a status: "exists" response with available info
+            existing_branch = ctx.git_ops.get_current_branch(wt_path)
+            plan_file_path = wt_path / ".PLAN.md"
+            json_response = _create_json_response(
+                worktree_name=name,
+                worktree_path=wt_path,
+                branch_name=existing_branch,
+                plan_file_path=plan_file_path if plan_file_path.exists() else None,
+                status="exists",
+            )
+            click.echo(json_response)
+            raise SystemExit(1)
+        else:
+            click.echo(f"Worktree path already exists: {wt_path}")
+            raise SystemExit(1)
 
     # Handle from-current-branch logic: switch current worktree first
     to_branch = None
     if from_current_branch:
-        # Determine which branch to switch to (use ref if provided, else main/master)
-        to_branch = ref if ref else ctx.git_ops.detect_default_branch(repo.root)
+        current_branch = ctx.git_ops.get_current_branch(Path.cwd())
+        if current_branch is None:
+            click.echo("Error: Unable to determine current branch", err=True)
+            raise SystemExit(1)
+
+        # Determine preferred branch to checkout (prioritize Graphite parent)
+        parent_branch = (
+            get_parent_branch(ctx, repo.root, current_branch) if current_branch else None
+        )
+
+        if parent_branch:
+            # Prefer Graphite parent branch
+            to_branch = parent_branch
+        elif ref:
+            # Use ref if provided
+            to_branch = ref
+        else:
+            # Fall back to default branch (main/master)
+            to_branch = ctx.git_ops.detect_default_branch(repo.root)
 
         # Check for edge case: can't move main to worktree then switch to main
-        current_branch = ctx.git_ops.get_current_branch(Path.cwd())
         if current_branch == to_branch:
             click.echo(
                 f"Error: Cannot use --from-current-branch when on '{current_branch}'.\n"
@@ -450,8 +529,14 @@ def create(
             )
             raise SystemExit(1)
 
-        # Switch the current worktree so the branch is free before creating the new worktree
-        ctx.git_ops.checkout_branch(Path.cwd(), to_branch)
+        # Check if target branch is available (not checked out in another worktree)
+        checkout_path = ctx.git_ops.is_branch_checked_out(repo.root, to_branch)
+        if checkout_path is not None:
+            # Target branch is in use, fall back to detached HEAD
+            ctx.git_ops.checkout_detached(Path.cwd(), current_branch)
+        else:
+            # Target branch is available, checkout normally
+            ctx.git_ops.checkout_branch(Path.cwd(), to_branch)
 
         # Create worktree with existing branch
         add_worktree(
@@ -496,20 +581,23 @@ def create(
     (wt_path / ".env").write_text(env_content, encoding="utf-8")
 
     # Move or copy plan file if provided
+    # Track plan file destination: set to .PLAN.md path only if --plan was provided
+    plan_file_destination: Path | None = None
     if plan_file:
-        plan_dest = wt_path / ".PLAN.md"
+        plan_file_destination = wt_path / ".PLAN.md"
         if keep_plan:
-            shutil.copy2(str(plan_file), str(plan_dest))
-            if not script:
-                click.echo(f"Copied plan to {plan_dest}")
+            shutil.copy2(str(plan_file), str(plan_file_destination))
+            if not script and not output_json:
+                click.echo(f"Copied plan to {plan_file_destination}")
         else:
-            shutil.move(str(plan_file), str(plan_dest))
-            if not script:
-                click.echo(f"Moved plan to {plan_dest}")
+            shutil.move(str(plan_file), str(plan_file_destination))
+            if not script and not output_json:
+                click.echo(f"Moved plan to {plan_file_destination}")
 
-    # Post-create commands
+    # Post-create commands (suppress output if JSON mode)
     if not no_post and cfg.post_create_commands:
-        click.echo("Running post-create commands...")
+        if not output_json:
+            click.echo("Running post-create commands...")
         run_commands_in_worktree(
             commands=cfg.post_create_commands,
             worktree_path=wt_path,
@@ -528,6 +616,16 @@ def create(
             comment=f"cd to {name}",
         )
         click.echo(str(script_path), nl=False)
+    elif output_json:
+        # Output JSON with worktree information
+        json_response = _create_json_response(
+            worktree_name=name,
+            worktree_path=wt_path,
+            branch_name=branch,
+            plan_file_path=plan_file_destination,
+            status="created",
+        )
+        click.echo(json_response)
     else:
         click.echo(f"Created workstack at {wt_path} checked out at branch '{branch}'")
         click.echo(f"\nworkstack switch {name}")
@@ -544,7 +642,13 @@ def run_commands_in_worktree(
     """
 
     for cmd in commands:
-        if shell:
-            subprocess.run([shell, "-lc", cmd], cwd=worktree_path, check=True)
-        else:
-            subprocess.run(shlex.split(cmd), cwd=worktree_path, check=True)
+        cmd_list = [shell, "-lc", cmd] if shell else shlex.split(cmd)
+        run_with_error_reporting(
+            cmd_list,
+            cwd=worktree_path,
+            error_prefix="Post-create command failed",
+            troubleshooting=[
+                "The worktree was created successfully, but a post-create command failed",
+                "You can still use the worktree or re-run the command manually",
+            ],
+        )
