@@ -1,5 +1,6 @@
 """Tests for the create command."""
 
+import json
 from pathlib import Path
 from unittest import mock
 
@@ -575,6 +576,10 @@ def test_create_uses_graphite_when_enabled() -> None:
 
         # Mock subprocess to simulate gt create
         with mock.patch("workstack.cli.commands.create.subprocess.run") as mock_run:
+            # Configure mock to return a successful result
+            mock_run.return_value.returncode = 0
+            mock_run.return_value.stdout = ""
+            mock_run.return_value.stderr = ""
             result = runner.invoke(cli, ["create", "test-feature"], obj=test_ctx)
 
         assert result.exit_code == 0, result.output
@@ -1153,3 +1158,580 @@ def test_create_keep_plan_without_plan_fails() -> None:
 
         assert result.exit_code == 1
         assert "--keep-plan requires --plan" in result.output
+
+
+def test_from_current_branch_with_main_in_use_prefers_graphite_parent() -> None:
+    """Test that --from-current-branch prefers Graphite parent when main is in use.
+
+    Scenario:
+    - Current worktree is on feature-2 (with Graphite parent feature-1)
+    - Root worktree has main checked out
+    - feature-1 is available (not checked out)
+
+    Expected: Should checkout feature-1 (the parent), not try to checkout main
+    """
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        base = Path.cwd()
+        repo_root = base / "repo"
+        repo_root.mkdir()
+        git_dir = repo_root / ".git"
+        git_dir.mkdir()
+
+        current_worktree = base / "wt-current"
+        current_worktree.mkdir()
+
+        workstacks_root = base / "workstacks"
+        workstacks_root.mkdir()
+        workstacks_dir = workstacks_root / repo_root.name
+        workstacks_dir.mkdir()
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Set up Graphite stack: main -> feature-1 -> feature-2
+        from tests.test_utils.graphite_helpers import setup_graphite_stack
+
+        setup_graphite_stack(
+            git_dir,
+            {
+                "main": {"parent": None, "children": ["feature-1"], "is_trunk": True},
+                "feature-1": {"parent": "main", "children": ["feature-2"]},
+                "feature-2": {"parent": "feature-1", "children": []},
+            },
+        )
+
+        git_ops = FakeGitOps(
+            worktrees={
+                repo_root: [
+                    WorktreeInfo(path=repo_root, branch="main"),
+                    WorktreeInfo(path=current_worktree, branch="feature-2"),
+                ]
+            },
+            current_branches={
+                repo_root: "main",
+                current_worktree: "feature-2",
+            },
+            default_branches={repo_root: "main"},
+            git_common_dirs={
+                current_worktree: git_dir,
+                repo_root: git_dir,
+            },
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        with mock.patch("pathlib.Path.cwd", return_value=current_worktree):
+            result = runner.invoke(cli, ["create", "--from-current-branch"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+        # Should checkout feature-1 (the Graphite parent), not main
+        assert (current_worktree, "feature-1") in git_ops.checked_out_branches
+
+
+def test_from_current_branch_with_parent_in_use_falls_back_to_detached_head() -> None:
+    """Test that --from-current-branch uses detached HEAD when parent is also in use.
+
+    Scenario:
+    - Current worktree is on feature-2 (with Graphite parent feature-1)
+    - Root worktree has main checked out
+    - Another worktree has feature-1 checked out
+
+    Expected: Should use detached HEAD as fallback since both main and parent are in use
+    """
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        base = Path.cwd()
+        repo_root = base / "repo"
+        repo_root.mkdir()
+        git_dir = repo_root / ".git"
+        git_dir.mkdir()
+
+        current_worktree = base / "wt-current"
+        current_worktree.mkdir()
+
+        other_worktree = base / "wt-other"
+        other_worktree.mkdir()
+
+        workstacks_root = base / "workstacks"
+        workstacks_root.mkdir()
+        workstacks_dir = workstacks_root / repo_root.name
+        workstacks_dir.mkdir()
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Set up Graphite stack: main -> feature-1 -> feature-2
+        from tests.test_utils.graphite_helpers import setup_graphite_stack
+
+        setup_graphite_stack(
+            git_dir,
+            {
+                "main": {"parent": None, "children": ["feature-1"], "is_trunk": True},
+                "feature-1": {"parent": "main", "children": ["feature-2"]},
+                "feature-2": {"parent": "feature-1", "children": []},
+            },
+        )
+
+        git_ops = FakeGitOps(
+            worktrees={
+                repo_root: [
+                    WorktreeInfo(path=repo_root, branch="main"),
+                    WorktreeInfo(path=current_worktree, branch="feature-2"),
+                    WorktreeInfo(path=other_worktree, branch="feature-1"),
+                ]
+            },
+            current_branches={
+                repo_root: "main",
+                current_worktree: "feature-2",
+                other_worktree: "feature-1",
+            },
+            default_branches={repo_root: "main"},
+            git_common_dirs={
+                current_worktree: git_dir,
+                repo_root: git_dir,
+                other_worktree: git_dir,
+            },
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        with mock.patch("pathlib.Path.cwd", return_value=current_worktree):
+            result = runner.invoke(cli, ["create", "--from-current-branch"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+        # Should use detached HEAD since both main and feature-1 are in use
+        assert len(git_ops.detached_checkouts) == 1
+        assert git_ops.detached_checkouts[0][0] == current_worktree
+        assert git_ops.detached_checkouts[0][1] == "feature-2"
+
+
+def test_from_current_branch_without_graphite_falls_back_to_main() -> None:
+    """Test that --from-current-branch falls back to main when no Graphite parent exists.
+
+    Scenario:
+    - Current worktree is on standalone-feature (not in any Graphite stack)
+    - Root worktree has other-branch checked out (not main)
+    - main is available
+
+    Expected: Should checkout main as fallback
+    """
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        base = Path.cwd()
+        repo_root = base / "repo"
+        repo_root.mkdir()
+        git_dir = repo_root / ".git"
+        git_dir.mkdir()
+
+        current_worktree = base / "wt-current"
+        current_worktree.mkdir()
+
+        workstacks_root = base / "workstacks"
+        workstacks_root.mkdir()
+        workstacks_dir = workstacks_root / repo_root.name
+        workstacks_dir.mkdir()
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Set up minimal Graphite stack (standalone-feature not in it)
+        from tests.test_utils.graphite_helpers import setup_graphite_stack
+
+        setup_graphite_stack(
+            git_dir,
+            {
+                "main": {"parent": None, "children": [], "is_trunk": True},
+            },
+        )
+
+        git_ops = FakeGitOps(
+            worktrees={
+                repo_root: [
+                    WorktreeInfo(path=repo_root, branch="other-branch"),
+                    WorktreeInfo(path=current_worktree, branch="standalone-feature"),
+                ]
+            },
+            current_branches={
+                repo_root: "other-branch",
+                current_worktree: "standalone-feature",
+            },
+            default_branches={repo_root: "main"},
+            git_common_dirs={
+                current_worktree: git_dir,
+                repo_root: git_dir,
+            },
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        with mock.patch("pathlib.Path.cwd", return_value=current_worktree):
+            result = runner.invoke(cli, ["create", "--from-current-branch"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+        # Should checkout main since no Graphite parent exists
+        assert (current_worktree, "main") in git_ops.checked_out_branches
+
+
+def test_from_current_branch_no_graphite_main_in_use_uses_detached_head() -> None:
+    """Test that --from-current-branch uses detached HEAD when no parent and main is in use.
+
+    Scenario:
+    - Current worktree is on standalone-feature (not in any Graphite stack)
+    - Root worktree has main checked out
+
+    Expected: Should use detached HEAD since no parent exists and main is in use
+    """
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        base = Path.cwd()
+        repo_root = base / "repo"
+        repo_root.mkdir()
+        git_dir = repo_root / ".git"
+        git_dir.mkdir()
+
+        current_worktree = base / "wt-current"
+        current_worktree.mkdir()
+
+        workstacks_root = base / "workstacks"
+        workstacks_root.mkdir()
+        workstacks_dir = workstacks_root / repo_root.name
+        workstacks_dir.mkdir()
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Set up minimal Graphite stack (standalone-feature not in it)
+        from tests.test_utils.graphite_helpers import setup_graphite_stack
+
+        setup_graphite_stack(
+            git_dir,
+            {
+                "main": {"parent": None, "children": [], "is_trunk": True},
+            },
+        )
+
+        git_ops = FakeGitOps(
+            worktrees={
+                repo_root: [
+                    WorktreeInfo(path=repo_root, branch="main"),
+                    WorktreeInfo(path=current_worktree, branch="standalone-feature"),
+                ]
+            },
+            current_branches={
+                repo_root: "main",
+                current_worktree: "standalone-feature",
+            },
+            default_branches={repo_root: "main"},
+            git_common_dirs={
+                current_worktree: git_dir,
+                repo_root: git_dir,
+            },
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        with mock.patch("pathlib.Path.cwd", return_value=current_worktree):
+            result = runner.invoke(cli, ["create", "--from-current-branch"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+        # Should use detached HEAD since no parent and main is in use
+        assert len(git_ops.detached_checkouts) == 1
+        assert git_ops.detached_checkouts[0][0] == current_worktree
+        assert git_ops.detached_checkouts[0][1] == "standalone-feature"
+
+
+def test_create_with_json_output() -> None:
+    """Test creating a worktree with JSON output."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        cwd = Path.cwd()
+        git_dir = cwd / ".git"
+        git_dir.mkdir()
+
+        workstacks_root = cwd / "workstacks"
+        workstacks_dir = workstacks_root / cwd.name
+        workstacks_dir.mkdir(parents=True)
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        git_ops = FakeGitOps(
+            git_common_dirs={cwd: git_dir},
+            default_branches={cwd: "main"},
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        result = runner.invoke(cli, ["create", "test-feature", "--json"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+
+        # Verify JSON output
+        output_data = json.loads(result.output)
+        assert output_data["worktree_name"] == "test-feature"
+        assert output_data["worktree_path"] == str(workstacks_dir / "test-feature")
+        assert output_data["branch_name"] == "test-feature"
+        assert output_data["plan_file"] is None
+        assert output_data["status"] == "created"
+
+        # Verify worktree was actually created
+        wt_path = workstacks_dir / "test-feature"
+        assert wt_path.exists()
+
+
+def test_create_existing_worktree_with_json() -> None:
+    """Test creating a worktree that already exists with JSON output."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        cwd = Path.cwd()
+        git_dir = cwd / ".git"
+        git_dir.mkdir()
+
+        workstacks_root = cwd / "workstacks"
+        workstacks_dir = workstacks_root / cwd.name
+        workstacks_dir.mkdir(parents=True)
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Create existing worktree
+        existing_wt = workstacks_dir / "existing-feature"
+        existing_wt.mkdir()
+
+        git_ops = FakeGitOps(
+            git_common_dirs={cwd: git_dir},
+            default_branches={cwd: "main"},
+            current_branches={existing_wt: "existing-branch"},
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        result = runner.invoke(cli, ["create", "existing-feature", "--json"], obj=test_ctx)
+
+        assert result.exit_code == 1, result.output
+
+        # Verify JSON error output
+        output_data = json.loads(result.output)
+        assert output_data["worktree_name"] == "existing-feature"
+        assert output_data["worktree_path"] == str(existing_wt)
+        assert output_data["branch_name"] == "existing-branch"
+        assert output_data["status"] == "exists"
+
+
+def test_create_json_and_script_mutually_exclusive() -> None:
+    """Test that --json and --script flags are mutually exclusive."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        cwd = Path.cwd()
+        git_dir = cwd / ".git"
+        git_dir.mkdir()
+
+        workstacks_root = cwd / "workstacks"
+        workstacks_dir = workstacks_root / cwd.name
+        workstacks_dir.mkdir(parents=True)
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        git_ops = FakeGitOps(
+            git_common_dirs={cwd: git_dir},
+            default_branches={cwd: "main"},
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        result = runner.invoke(cli, ["create", "test-feature", "--json", "--script"], obj=test_ctx)
+
+        # Should fail with validation error
+        assert result.exit_code == 1
+        assert "Cannot use both --json and --script" in result.output
+
+
+def test_create_with_json_and_plan_file() -> None:
+    """Test creating a worktree with JSON output and plan file."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        cwd = Path.cwd()
+        git_dir = cwd / ".git"
+        git_dir.mkdir()
+
+        workstacks_root = cwd / "workstacks"
+        workstacks_dir = workstacks_root / cwd.name
+        workstacks_dir.mkdir(parents=True)
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        # Create a plan file - name will be derived from filename
+        plan_file = cwd / "test-feature-plan.md"
+        plan_file.write_text("# Implementation Plan\n\nTest plan content", encoding="utf-8")
+
+        git_ops = FakeGitOps(
+            git_common_dirs={cwd: git_dir},
+            default_branches={cwd: "main"},
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        # Don't provide NAME - it's derived from plan filename
+        result = runner.invoke(
+            cli,
+            ["create", "--json", "--plan", str(plan_file)],
+            obj=test_ctx,
+        )
+
+        assert result.exit_code == 0, result.output
+
+        # Verify JSON output includes plan file
+        output_data = json.loads(result.output)
+        # Name is derived from "test-feature-plan.md" -> "test-feature"
+        assert output_data["worktree_name"] == "test-feature"
+        wt_path = workstacks_dir / "test-feature"
+        expected_plan_path = wt_path / ".PLAN.md"
+        assert output_data["plan_file"] == str(expected_plan_path)
+        assert output_data["status"] == "created"
+
+        # Verify plan file was moved
+        assert expected_plan_path.exists()
+        assert not plan_file.exists()  # Original should be moved, not copied
+
+
+def test_create_with_json_no_plan() -> None:
+    """Test that JSON output has null plan_file when no plan is provided."""
+    runner = CliRunner()
+    with runner.isolated_filesystem():
+        cwd = Path.cwd()
+        git_dir = cwd / ".git"
+        git_dir.mkdir()
+
+        workstacks_root = cwd / "workstacks"
+        workstacks_dir = workstacks_root / cwd.name
+        workstacks_dir.mkdir(parents=True)
+
+        config_toml = workstacks_dir / "config.toml"
+        config_toml.write_text("", encoding="utf-8")
+
+        git_ops = FakeGitOps(
+            git_common_dirs={cwd: git_dir},
+            default_branches={cwd: "main"},
+        )
+        global_config_ops = FakeGlobalConfigOps(
+            exists=True,
+            workstacks_root=workstacks_root,
+            use_graphite=False,
+        )
+
+        test_ctx = WorkstackContext(
+            git_ops=git_ops,
+            global_config_ops=global_config_ops,
+            github_ops=FakeGitHubOps(),
+            graphite_ops=FakeGraphiteOps(),
+            shell_ops=FakeShellOps(),
+            dry_run=False,
+        )
+
+        result = runner.invoke(cli, ["create", "test-feature", "--json"], obj=test_ctx)
+
+        assert result.exit_code == 0, result.output
+
+        # Verify JSON output has null plan_file
+        output_data = json.loads(result.output)
+        assert output_data["plan_file"] is None
+        assert output_data["status"] == "created"
