@@ -71,7 +71,11 @@ class FakeGitOps(GitOps):
         default_branches: dict[Path, str] | None = None,
         git_common_dirs: dict[Path, Path] | None = None,
         branch_heads: dict[str, str] | None = None,
+        commit_messages: dict[str, str] | None = None,
         staged_repos: set[Path] | None = None,
+        file_statuses: dict[Path, tuple[list[str], list[str], list[str]]] | None = None,
+        ahead_behind: dict[tuple[Path, str], tuple[int, int]] | None = None,
+        recent_commits: dict[Path, list[dict[str, str]]] | None = None,
     ) -> None:
         """Create FakeGitOps with pre-configured state.
 
@@ -81,20 +85,29 @@ class FakeGitOps(GitOps):
             default_branches: Mapping of repo_root -> default branch
             git_common_dirs: Mapping of cwd -> git common directory
             branch_heads: Mapping of branch name -> commit SHA
+            commit_messages: Mapping of commit SHA -> commit message
             staged_repos: Set of repo roots that should report staged changes
+            file_statuses: Mapping of cwd -> (staged, modified, untracked) files
+            ahead_behind: Mapping of (cwd, branch) -> (ahead, behind) counts
+            recent_commits: Mapping of cwd -> list of commit info dicts
         """
         self._worktrees = worktrees or {}
         self._current_branches = current_branches or {}
         self._default_branches = default_branches or {}
         self._git_common_dirs = git_common_dirs or {}
         self._branch_heads = branch_heads or {}
+        self._commit_messages = commit_messages or {}
         self._repos_with_staged_changes: set[Path] = staged_repos or set()
+        self._file_statuses = file_statuses or {}
+        self._ahead_behind = ahead_behind or {}
+        self._recent_commits = recent_commits or {}
 
         # Mutation tracking
         self._deleted_branches: list[str] = []
         self._added_worktrees: list[tuple[Path, str | None]] = []
         self._removed_worktrees: list[Path] = []
         self._checked_out_branches: list[tuple[Path, str]] = []
+        self._detached_checkouts: list[tuple[Path, str]] = []
 
     def list_worktrees(self, repo_root: Path) -> list[WorktreeInfo]:
         """List all worktrees in the repository."""
@@ -190,6 +203,8 @@ class FakeGitOps(GitOps):
                 if wt.path.resolve() == cwd.resolve():
                     self._worktrees[repo_root][i] = WorktreeInfo(path=wt.path, branch=None)
                     break
+        # Track the detached checkout
+        self._detached_checkouts.append((cwd, ref))
 
     def delete_branch_with_graphite(self, repo_root: Path, branch: str, *, force: bool) -> None:
         """Track which branches were deleted (mutates internal state)."""
@@ -211,6 +226,23 @@ class FakeGitOps(GitOps):
         """Get the commit SHA at the head of a branch."""
         return self._branch_heads.get(branch)
 
+    def get_commit_message(self, repo_root: Path, commit_sha: str) -> str | None:
+        """Get the commit message for a given commit SHA."""
+        return self._commit_messages.get(commit_sha)
+
+    def get_file_status(self, cwd: Path) -> tuple[list[str], list[str], list[str]]:
+        """Get lists of staged, modified, and untracked files."""
+        return self._file_statuses.get(cwd, ([], [], []))
+
+    def get_ahead_behind(self, cwd: Path, branch: str) -> tuple[int, int]:
+        """Get number of commits ahead and behind tracking branch."""
+        return self._ahead_behind.get((cwd, branch), (0, 0))
+
+    def get_recent_commits(self, cwd: Path, *, limit: int = 5) -> list[dict[str, str]]:
+        """Get recent commit information."""
+        commits = self._recent_commits.get(cwd, [])
+        return commits[:limit]
+
     @property
     def deleted_branches(self) -> list[str]:
         """Get the list of branches that have been deleted.
@@ -244,3 +276,12 @@ class FakeGitOps(GitOps):
         This property is for test assertions only.
         """
         return self._checked_out_branches.copy()
+
+    @property
+    def detached_checkouts(self) -> list[tuple[Path, str]]:
+        """Get list of detached HEAD checkouts during test.
+
+        Returns list of (cwd, ref) tuples.
+        This property is for test assertions only.
+        """
+        return self._detached_checkouts.copy()
